// (c) Copyright 2012 Cloudera, Inc. All rights reserved.
define([
  "cloudera/Util",
  "cloudera/chart/TimeRange",
  "cloudera/cmf/charts/ChartsSearch",
  "cloudera/cmf/charts/ChartsSearchResult"
], function(Util, TimeRange, ChartsSearch, ChartsSearchResult) {

  /**
   * The JavaScript for the Charts Search page.
   *
   * options = {
   *   searchContainer: (required) "the selector of the parent container of the Search panel",
   *   resultContainer: (required) "the selector of the parent container of the result",
   *   timeRange:       (required) the initial time range,
   *   recentUri:       (required) "the URL to get a list of recent queries",
   *   searchUri:       (required) "the URL of this page, used for changing the page location when a recent entry is selected",
   *   plot:            (required) what to plot,
   *   metric:          (optional) "the initial metric search",
   *   viewName:        (optional) "the name of the view when this page is in edit mode."
   *   savePlotUrl:     (optional) "the URL to save a plot in edit mode."
   *   returnUrl:       (optional) "the return url after user clicks the Save button in edit mode",
   *   context:         (optional) the context object in edit/add mode,
   *   mode:            (required) what mode are we in, edit/add/<empty>"
   * }
   */
  return function(options) {
    var self = this;

    var searchOptions = {
      container: options.searchContainer,
      metric: options.metric,
      tsquery: options.plot.tsquery,
      recentUri: options.recentUri,
      searchUri: options.searchUri,
      context: options.context
    };
    var searchModule = new ChartsSearch(searchOptions);

    var resultOptions = {
      container: options.resultContainer,
      timeRange : options.timeRange,
      addPlotUri: options.addPlotUri,
      plot: options.plot,
      context: options.context,
      viewName: options.viewName,
      savePlotUrl: options.savePlotUrl,
      returnUrl: options.returnUrl,
      mode: options.mode
    };
    var resultModule = new ChartsSearchResult(resultOptions);

    self.unsubscribe = function() {
      resultModule.unsubscribe();
    };
    $(".showTooltip").tooltip();
  };
});
